﻿using Dapper;
using EVCB_OCPP.TaskScheduler.Models;
using EVCB_OCPP.TaskScheduler.Services;
using Newtonsoft.Json;
using Quartz;
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using static Common.Logging.Configuration.ArgUtils;

namespace EVCB_OCPP.TaskScheduler.Jobs
{
    public class ResetChargerJob : IJob
    {
        private NLog.ILogger logger = NLog.LogManager.GetCurrentClassLogger();
        private string mainDBConnectString = ConfigurationManager.ConnectionStrings["MainDBContext"].ToString();
        public async Task Execute(IJobExecutionContext context)
        {
            logger.Info(this.ToString() + " :Starting........");

            List<string> chargers = new List<string>() { "DSYC152U00D5PHN2240A001A1", "DSYC152U00D5PHN2240A002A1", "DSYC152U00D5PHN2240A003A1", "DSYC182U0UD3PHN2240A001A1", "DSYC182U0UD3PHN2240A002A1", "DSYC182U0UD3PHN2240A003A1" };

            foreach (var charger in chargers)
            {
                string sqlString = "INSERT INTO [dbo].[ServerMessage] (\"SerialNo\",\"OutAction\",\"OutRequest\",\"InMessage\",\"CreatedOn\",\"CreatedBy\",\"ReceivedOn\",\"ChargeBoxId\",\"UpdatedOn\")" +
                       "VALUES( @SerialNo,@OutAction,@OutRequest,@InMessage,@CreatedOn,@CreatedBy,@ReceivedOn,@ChargeBoxId,@UpdatedOn); ";
                using (var dbConn = new SqlConnection(mainDBConnectString))
                {
                    dbConn.Open();
                    var parameters = new DynamicParameters();
                    parameters.Add("@SerialNo", Guid.NewGuid().ToString(), System.Data.DbType.String);
                    parameters.Add("@OutAction", "Reset", System.Data.DbType.String);
                    parameters.Add("@OutRequest", @"{""type"":""Hard""}", System.Data.DbType.String);
                    parameters.Add("@InMessage", string.Empty, System.Data.DbType.String);
                    parameters.Add("@CreatedOn", DateTime.UtcNow, System.Data.DbType.DateTime);
                    parameters.Add("@ReceivedOn", DefaultSetting.DefaultNullTime, System.Data.DbType.DateTime);
                    parameters.Add("@CreatedBy", "Task", System.Data.DbType.String);
                    parameters.Add("@ChargeBoxId", charger, System.Data.DbType.String);
                    parameters.Add("@UpdatedOn", DefaultSetting.DefaultNullTime, System.Data.DbType.DateTime);

                    await dbConn.ExecuteAsync(sqlString, parameters);

                }
            }

            logger.Info(this.ToString() + " :Finished........");          
        }     
    }
}
